function [ret,x0,str]=fsimdemo(t,x,u,flag);
%FSIMDEMO	is the M-file description of the SIMULINK system named FSIMDEMO.
%	The block-diagram can be displayed by typing: FSIMDEMO.
%
%	SYS=FSIMDEMO(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes FSIMDEMO to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling FSIMDEMO with a FLAG of zero:
%	[SIZES]=FSIMDEMO([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[5,59,460,191])
     open_system(sys)
end;
set_param(sys,'algorithm',		'RK-45')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'999999')
set_param(sys,'Min step size',	'0.0001')
set_param(sys,'Max step size',	'10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')


%     Subsystem  ['Mamdani''s FLC'].

new_system([sys,'/',['Mamdani''s FLC']])
set_param([sys,'/',['Mamdani''s FLC']],'Location',[4,380,131,533])
set_param([sys,'/',['Mamdani''s FLC']],...
		'Mask Display','Mamdani''s FLC',...
		'Mask Type','Mamdani''s fuzzy controller')
set_param([sys,'/',['Mamdani''s FLC']],...
		'Mask Dialogue','eval(''f = get(0,''''children''''); for i = f, close(i); end; clear; [rls, mfs, inputs, outputs, nlab, labels] = txt2rls(''''mamdani.rb''''); mamdani'');',...
		'Mask Translate','')
set_param([sys,'/',['Mamdani''s FLC']],...
		'Mask Help','')


%     Finished composite block ['Mamdani''s FLC'].

set_param([sys,'/',['Mamdani''s FLC']],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[15,9,135,40])


%     Subsystem  ['Sugeno''s FLC'].

new_system([sys,'/',['Sugeno''s FLC']])
set_param([sys,'/',['Sugeno''s FLC']],'Location',[4,380,131,533])
set_param([sys,'/',['Sugeno''s FLC']],...
		'Mask Display','Sugeno''s FLC',...
		'Mask Type','Sugeno''s fuzzy controller')
set_param([sys,'/',['Sugeno''s FLC']],...
		'Mask Dialogue','eval(''f = get(0,''''children''''); for i = f, close(i); end; clear; [rls, mfs, inputs, outputs, nlab, labels] = txt2rls(''''gaindemo.rb''''); gaindemo'');',...
		'Mask Translate','')
set_param([sys,'/',['Sugeno''s FLC']],...
		'Mask Help','')


%     Finished composite block ['Sugeno''s FLC'].

set_param([sys,'/',['Sugeno''s FLC']],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[160,9,280,40])


%     Subsystem  'FLC blocks'.

new_system([sys,'/','FLC blocks'])
set_param([sys,'/','FLC blocks'],'Location',[4,380,131,533])
set_param([sys,'/','FLC blocks'],...
		'Mask Display','FLC blocks',...
		'Mask Type','Fuzzy controller blocks',...
		'Mask Dialogue','eval(''f = get(0,''''children''''); for i = f, close(i); end; clear; fblocks'');',...
		'Mask Translate','')
set_param([sys,'/','FLC blocks'],...
		'Mask Help','')


%     Finished composite block 'FLC blocks'.

set_param([sys,'/','FLC blocks'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[305,9,425,40])


%     Subsystem  'Rule chaining'.

new_system([sys,'/','Rule chaining'])
set_param([sys,'/','Rule chaining'],'Location',[4,380,131,533])
set_param([sys,'/','Rule chaining'],...
		'Mask Display','Rule chaining',...
		'Mask Type','Rule chaining with relational composition',...
		'Mask Dialogue','eval(''f = get(0,''''children''''); for i = f, close(i); end; clear; reldemo'');')
set_param([sys,'/','Rule chaining'],...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block 'Rule chaining'.

set_param([sys,'/','Rule chaining'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[15,59,135,90])


%     Subsystem  ['Sugeno''s model'].

new_system([sys,'/',['Sugeno''s model']])
set_param([sys,'/',['Sugeno''s model']],'Location',[4,380,131,533])
set_param([sys,'/',['Sugeno''s model']],...
		'Mask Display','Sugeno''s model',...
		'Mask Type','Sugeno--Takagi''s fuzzy model',...
		'Mask Dialogue','eval(''f = get(0,''''children''''); for i = f, close(i); end; clear; sugdemo'');')
set_param([sys,'/',['Sugeno''s model']],...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block ['Sugeno''s model'].

set_param([sys,'/',['Sugeno''s model']],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[160,59,280,90])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
