function [ret,x0,str,ts,xts]=gaindemo(t,x,u,flag);
%GAINDEMO	is the M-file description of the SIMULINK system named GAINDEMO.
%	The block-diagram can be displayed by typing: GAINDEMO.
%
%	SYS=GAINDEMO(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes GAINDEMO to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling GAINDEMO with a FLAG of zero:
%	[SIZES]=GAINDEMO([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,58,569,382])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     '30')
set_param(sys,'Min step size', '0.5')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Rules editor'.

new_system([sys,'/','Rules editor'])
set_param([sys,'/','Rules editor'],'Location',[4,380,131,533])
set_param([sys,'/','Rules editor'],...
		'Mask Display','Edit rules',...
		'Mask Type','Rule-base editor')
set_param([sys,'/','Rules editor'],...
		'Mask Dialogue','eval([''!notepad '' get_param ''.rb'']); eval([''[rls, initmfs, inputs, outputs, nlab, labels] = txt2rls('''''' get_param ''''''); if exist(''''mfs'''')~=1, mfs = initmfs; elseif length(mfs) == 0, mfs = initmfs; end;'']);')


%     Finished composite block 'Rules editor'.

set_param([sys,'/','Rules editor'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[15,9,80,40])


%     Subsystem  'Rules editor1'.

new_system([sys,'/','Rules editor1'])
set_param([sys,'/','Rules editor1'],'Location',[4,380,131,533])
set_param([sys,'/','Rules editor1'],...
		'Mask Display','Compile rulebase',...
		'Mask Type','Rule-base editor',...
		'Mask Dialogue','eval([''[rls, mfs, inputs, outputs, nlab, labels] = txt2rls('''''' get_param '''''');'']);')


%     Finished composite block 'Rules editor1'.

set_param([sys,'/','Rules editor1'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[90,9,225,40])


%     Subsystem  'More Info'.

new_system([sys,'/','More Info'])
set_param([sys,'/','More Info'],'Location',[489,103,877,287])

add_block('built-in/Note',[sys,'/',['More Info/This demonstration compares a proportional controller',13,'vers. fuzzy gain-scheduling control',13,'on a nonlinear third-order plant.  ']])
set_param([sys,'/',['More Info/This demonstration compares a proportional controller',13,'vers. fuzzy gain-scheduling control',13,'on a nonlinear third-order plant.  ']],...
		'position',[190,10,195,15])

add_block('built-in/Note',[sys,'/',['More Info/To strart click on "Compile rule-base" first. ',13,'On other systems than MS-Windows, you may want ',13,'to change the "Edit rules" icon in order to set your',13,'preferred text editor. ']])
set_param([sys,'/',['More Info/To strart click on "Compile rule-base" first. ',13,'On other systems than MS-Windows, you may want ',13,'to change the "Edit rules" icon in order to set your',13,'preferred text editor. ']],...
		'position',[193,60,198,65])
set_param([sys,'/','More Info'],...
		'Mask Display','Help')


%     Finished composite block 'More Info'.

set_param([sys,'/','More Info'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[445,10,510,40])


%     Subsystem  'Load data'.

new_system([sys,'/','Load data'])
set_param([sys,'/','Load data'],'Location',[4,380,131,533])
set_param([sys,'/','Load data'],...
		'Mask Display','Load',...
		'Mask Type',' ',...
		'Mask Dialogue','eval([''load '' get_param]);')


%     Finished composite block 'Load data'.

set_param([sys,'/','Load data'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[380,9,435,40])


%     Subsystem  'Save data'.

new_system([sys,'/','Save data'])
set_param([sys,'/','Save data'],'Location',[4,380,131,533])
set_param([sys,'/','Save data'],...
		'Mask Display','Save',...
		'Mask Type',' ',...
		'Mask Dialogue','eval([''save '' get_param]); ')


%     Finished composite block 'Save data'.

set_param([sys,'/','Save data'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[315,9,370,40])


%     Subsystem  'LIst rules'.

new_system([sys,'/','LIst rules'])
set_param([sys,'/','LIst rules'],'Location',[-10,380,117,533])
set_param([sys,'/','LIst rules'],...
		'Mask Display','LIst rules',...
		'Mask Type',' ',...
		'Mask Dialogue','eval(''disp(rls2txt(rls, mfs, inputs, outputs, nlab, labels));'');')


%     Finished composite block 'LIst rules'.

set_param([sys,'/','LIst rules'],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[240,9,305,40])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'Gain','0.05',...
		'position',[200,231,255,269])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[120,230,150,270])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[0,0,451,221])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum'])
set_param([sys,'/','UnNamed1/Sum'],...
		'hide name',0,...
		'position',[270,60,300,100])

add_block('built-in/Product',[sys,'/','UnNamed1/Product1'])
set_param([sys,'/','UnNamed1/Product1'],...
		'hide name',0,...
		'position',[80,90,110,125])

add_block('built-in/Product',[sys,'/','UnNamed1/Product'])
set_param([sys,'/','UnNamed1/Product'],...
		'hide name',0,...
		'position',[135,70,165,105])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed1/Transfer Fcn'])
set_param([sys,'/','UnNamed1/Transfer Fcn'],...
		'hide name',0,...
		'Denominator','[1 1 1]',...
		'position',[185,69,240,111])

add_block('built-in/Inport',[sys,'/','UnNamed1/in_1'])
set_param([sys,'/','UnNamed1/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[390,70,410,90])

add_block('built-in/Inport',[sys,'/','UnNamed1/in_2'])
set_param([sys,'/','UnNamed1/in_2'],...
		'Port','2',...
		'position',[15,15,35,35])

add_block('built-in/Integrator',[sys,'/','UnNamed1/Integrator1'])
set_param([sys,'/','UnNamed1/Integrator1'],...
		'hide name',0,...
		'Initial','ic',...
		'position',[325,58,350,102])
add_line([sys,'/','UnNamed1'],[40,25;250,25;250,70;265,70])
add_line([sys,'/','UnNamed1'],[115,110;130,95])
add_line([sys,'/','UnNamed1'],[170,90;180,90])
add_line([sys,'/','UnNamed1'],[40,80;130,80])
add_line([sys,'/','UnNamed1'],[355,80;355,140;50,140;50,115;75,115])
add_line([sys,'/','UnNamed1'],[50,115;50,100;75,100])
add_line([sys,'/','UnNamed1'],[245,90;265,90])
add_line([sys,'/','UnNamed1'],[305,80;320,80])
add_line([sys,'/','UnNamed1'],[355,80;385,80])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','dpoly([''y^2''],[1 1 1 0],''s'')',...
		'Mask Dialogue','Non-linear 3-rd order process |Initial condition: ',...
		'Mask Translate','ic = @1;')
set_param([sys,'/','UnNamed1'],...
		'Mask Help','Unmask this block to see the system.',...
		'Mask Entries','2\/')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'hide name',0,...
		'position',[360,231,440,284])

add_block('built-in/Step Fcn',[sys,'/','Setpoint'])
set_param([sys,'/','Setpoint'],...
		'Before','2',...
		'After','5',...
		'position',[25,115,45,135])

add_block('built-in/Step Fcn',[sys,'/','Disturbance'])
set_param([sys,'/','Disturbance'],...
		'Time','2',...
		'After','0',...
		'position',[250,155,270,175])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[4,46,455,267])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'hide name',0,...
		'position',[270,60,300,100])

add_block('built-in/Product',[sys,'/','UnNamed/Product1'])
set_param([sys,'/','UnNamed/Product1'],...
		'hide name',0,...
		'position',[80,90,110,125])

add_block('built-in/Product',[sys,'/','UnNamed/Product'])
set_param([sys,'/','UnNamed/Product'],...
		'hide name',0,...
		'position',[135,70,165,105])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed/Transfer Fcn'])
set_param([sys,'/','UnNamed/Transfer Fcn'],...
		'hide name',0,...
		'Denominator','[1 1 1]',...
		'position',[185,69,240,111])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[390,70,410,90])

add_block('built-in/Inport',[sys,'/','UnNamed/in_2'])
set_param([sys,'/','UnNamed/in_2'],...
		'Port','2',...
		'position',[15,15,35,35])

add_block('built-in/Integrator',[sys,'/','UnNamed/Integrator1'])
set_param([sys,'/','UnNamed/Integrator1'],...
		'hide name',0,...
		'Initial','ic',...
		'position',[325,58,350,102])
add_line([sys,'/','UnNamed'],[40,25;250,25;250,70;265,70])
add_line([sys,'/','UnNamed'],[115,110;130,95])
add_line([sys,'/','UnNamed'],[170,90;180,90])
add_line([sys,'/','UnNamed'],[40,80;130,80])
add_line([sys,'/','UnNamed'],[355,80;355,140;50,140;50,115;75,115])
add_line([sys,'/','UnNamed'],[50,115;50,100;75,100])
add_line([sys,'/','UnNamed'],[245,90;265,90])
add_line([sys,'/','UnNamed'],[305,80;320,80])
add_line([sys,'/','UnNamed'],[355,80;385,80])
set_param([sys,'/','UnNamed'],...
		'Mask Display','dpoly([''y^2''],[1 1 1 0],''s'')',...
		'Mask Dialogue','Non-linear 3-rd order process |Initial condition: ',...
		'Mask Translate','ic = @1;',...
		'Mask Help','Unmask this block to see the system.')
set_param([sys,'/','UnNamed'],...
		'Mask Entries','2\/')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'hide name',0,...
		'position',[365,111,445,164])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[110,115,140,155])

add_block('built-in/Product',[sys,'/','Product'])
set_param([sys,'/','Product'],...
		'hide name',0,...
		'position',[255,110,290,145])


%     Subsystem  'Green'.

new_system([sys,'/','Green'])
set_param([sys,'/','Green'],'Location',[4,68,278,261])

add_block('built-in/S-Function',[sys,'/',['Green/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Green/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunplot',...
		'parameters','figno,ax, color',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Green/x'])
set_param([sys,'/','Green/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Green'],[90,65;125,65])
set_param([sys,'/','Green'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Green'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter figure, plotting ranges and line type.|Figure:|Time range:|y-min:|y-max:|Line type (rgbw-:*):')
set_param([sys,'/','Green'],...
		'Mask Translate','figno = @1; color = @5; ax = [0, @2, @3, @4];')
set_param([sys,'/','Green'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works.',...
		'Mask Entries','1\/30\/0\/10\/''g-''\/')


%     Finished composite block 'Green'.

set_param([sys,'/','Green'],...
		'Drop Shadow',4,...
		'position',[505,121,535,159])


%     Subsystem  'Red'.

new_system([sys,'/','Red'])
set_param([sys,'/','Red'],'Location',[4,68,278,261])

add_block('built-in/Inport',[sys,'/','Red/x'])
set_param([sys,'/','Red/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Red/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Red/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunplot',...
		'parameters','figno,ax, color',...
		'position',[130,55,180,75])
add_line([sys,'/','Red'],[90,65;125,65])
set_param([sys,'/','Red'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Red'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter figure, plotting ranges and line type.|Figure:|Time range:|y-min:|y-max:|Line type (rgbw-:*):')
set_param([sys,'/','Red'],...
		'Mask Translate','figno = @1; color = @5; ax = [0, @2, @3, @4];')
set_param([sys,'/','Red'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works.',...
		'Mask Entries','1\/30\/0\/10\/''r-''\/')


%     Finished composite block 'Red'.

set_param([sys,'/','Red'],...
		'Drop Shadow',4,...
		'position',[505,241,535,279])

add_block('built-in/S-Function',[sys,'/','Fuzzy inference'])
set_param([sys,'/','Fuzzy inference'],...
		'orientation',2,...
		'hide name',0,...
		'function name','sfuninf',...
		'parameters','rls, mfs, def',...
		'Mask Display','Fuzzy supervisor',...
		'Mask Type','Fuzzy inference block')
set_param([sys,'/','Fuzzy inference'],...
		'Mask Dialogue','MIN-MAX inference with \n fuzzy means defuzzification|Rule matrix: |Membership functions matrix: |Default output:',...
		'Mask Translate','rls = @1; mfs = @2; def = @3;')
set_param([sys,'/','Fuzzy inference'],...
		'Mask Help','Fuzzy inference block can be used as a direct fuzzy controller or as a fuzzy supervisor. For details on dialog parameters see INFER.',...
		'Mask Entries','rls\/mfs\/0\/')
set_param([sys,'/','Fuzzy inference'],...
		'position',[240,58,385,92])
add_line(sys,[275,165;320,165;320,150;360,150])
add_line(sys,[320,165;320,270;355,270])
add_line(sys,[50,125;105,125])
add_line(sys,[65,125;65,240;115,240])
add_line(sys,[260,250;320,250;355,245])
add_line(sys,[445,260;500,260])
add_line(sys,[490,260;490,300;90,300;90,260;115,260])
add_line(sys,[155,250;195,250])
add_line(sys,[295,130;315,125;360,125])
add_line(sys,[145,135;250,135])
add_line(sys,[450,140;500,140])
add_line(sys,[490,140;490,210;90,210;90,145;105,145])
add_line(sys,[490,140;490,75;390,75])
add_line(sys,[235,75;155,75;155,120;250,120])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
