function  [sys, x0]  = sfundof(t,x,u,flag,figno,rls,mfs,domain,tnorm,par)
% SFUNDOF an S-function which calculates the degrees of fulfilment.
%
%       This M-file is designed to be used in a SIMULINK S-function block.
%       It uses the Fuzzy Toolbox functions DOFMIN and DOFTN.
%	
%       The input arguments are
%       figno:          Figure number (0 for no on-line plot).
%       rls:            Rule base matrix.
%       mfs:            Membership functions.
%       domain:         Domain for point-wise defined membership functions.
%       tnorm:          T-norm (string), M-file function must have
%                       the same synopsis as MATLAB function MIN.
%                       An additional parameter can be passed for
%                       parametric t-norms. If [], default MIN is used.
%       par:            T-norm parameter ([] for non-parametric
%                       operators).

% (c) Robert Babuska, December 1993

if abs(flag) == 2                       % state
   sys = x;

elseif flag == 3                        % output
    if length(tnorm) == 0,
      sys = dofmin(rls,mfs,u',domain)';
    else
      sys = doftn(rls,mfs,u',domain,tnorm,par)';
    end;
   if figno ~= 0,
     [xx,yy] = bar(1:size(rls,1),sys);
     set(x,'ydata',yy);
   end;
elseif flag  == 0,
  nrules = size(rls,1);
  % [cont, discr, outputs, inputs, roots, feedthrough]
  sys = [0, 1, nrules, size(rls,2)-1, 0,    1];
  x0 = 0;
  if figno ~= 0,
    while ~any(get(0,'Children')==figno),
       figure('Visible','off');
    end
    set(figno,'Visible','off');
    oldfig = get(0,'CurrentFigure');
    set(0,'CurrentFigure',figno);
    [xx,yy] = bar(1:nrules,zeros(nrules,1));
    clf;
    x0 = plot(xx,yy,'g','EraseMode','background');
    axis([min(xx) max(xx) 0 1]);
    set(gca,'box','off');
    set(figno,'BackingStore','off','Visible','on')
    set(0,'CurrentFigure',oldfig);
  end;
else
  % Other flag options not defined.
  sys = [];
end

