function  [sys, x0]  = sfunfset(t,x,u,flag,figno,nsets,domain,color)
%SFUNFSET S-function for a fuzzy set scope.
%
%	This M-file is designed to be used in a SIMULINK S-function block.
%
%       The input arguments are
%       figno:          Figure number.
%       nsets:          Number of input fuzzy sets.
%       domain:         Fuzzy sets domain.
%       color:          Color.

% (c) Robert Babuska, December 1993

if abs(flag) == 2       % A real time hit

        sys = x;
        y = zeros(nsets,length(domain));
        y(:) = u;
        for i = nsets : -1: 1,
          set(x(i),'ydata',y(i,:));
        end;

elseif flag  == 0,      % Initialization

	% Return system sizes
        % 0 continuous states, nsets discrete states
        % 0 outputs, nsets*length(domain) inputs, 0 roots,
        % no direct feed-through.
        sys = [0;nsets;0;nsets*length(domain);0;1];

        while ~any(get(0,'Children')==figno),
           figure('Visible','off');
        end
        set(figno,'Visible','off');
        oldfig = get(0,'CurrentFigure');
        set(0,'CurrentFigure',figno);
        clf;
        hold on;
        for i = nsets : -1 : 1,
           x0(i) = ...
           plot(domain,zeros(size(domain)),color,'EraseMode','background');
        end;
        axis([min(domain) max(domain) 0 1]);
        hold off;
        set(figno,'Visible','on')
        set(0,'CurrentFigure',oldfig);
else
	% Other flag options not defined.
	sys = [];
end
