function [y,DOF] = infer(rls,mfs,x,def)
% INFER fuzzy inference routine.
%
% [Y,DOF] = INFER(RLS,MFS,X,DEF)
%
% Inputs:       RLS - rule matrix
%               MFS - membership function matrix
%               X   - input vector or matrix
%               DEF - default value returned when
%                     no rules are applicable
%                     (optional, defaults to 0)
%
% Output:       Y   - output vector or matrix
%               DOF - degrees of fulfillment of every rule premise
%
% MIN-MAX inference and fast center-of-area defuzzification is used.
%
% See also TXT2RLS, RLS2TXT, MFSET, MFGET, DOFMIN, DOFPROD.

% (c) Robert Babuska, December 1993

if nargin < 4, def = 0; end;                            % no default supplied
[k,ninps] = size(x); [nrules,nio] = size(rls);
[nmfs,npoints] = size(mfs); nmfs = nmfs + 1;            % add ANY
w = rls(:,1); rls = rls(:,2:nio);                       % extract weights
nio = nio - 1; nouts = nio - ninps;                     % number of outputs
DOF = zeros(nrules,k);                                  % transposed DOF
cons = rls(:,ninps+1:nio)';                             % extract consequents
rls  = rls(:,1:ninps)';                                 % extract antecedents
aux = ones(ninps,k*nrules);                             % for rls expansion
grades = aux';                                          % prepare for grades
aux(:) = rls(:)*aux(1,1:k);                             % expand rls
rls = zeros(nrules,k*ninps);
rls(:) = aux';
ANYmask = rls == 0;                                     % find zeros (ANY)
rls(ANYmask) = nmfs*grades(ANYmask);                    % index for ANY
mask = rls < 0;                                         % find NOT in rules
sgn = -mask + (rls >= 0);                               % not(A) = 1 - A
shift = ones(nrules,1)*[0 nmfs*(1:k*ninps-1)];          % find index shift
rls = abs(rls) + shift;
g = mgrade(x(:)',[mfs;[0 0 0 0 0]]);                    % calculate all grades
grades(:) = mask + sgn .* g(rls);                       % select using rls
aux = ones(1,k*nrules);
DOF(:) = min([aux;grades']);                            % calculate min
DOF = w*aux(1,1:k).*DOF;                                % weight by w
DOF1 = zeros(nrules,k*nouts);                           % expand DOF's
DOF1(:) = DOF(:)*ones(1,nouts);
aux = ones(nouts,k*nrules);                             % expand cons
aux(:) = cons(:)*aux(1,1:k); cons = DOF1;
cons(:) = aux';
ANYmask = (cons~=0);                                    % find 0 in cons
DOF1 = ANYmask.*DOF1;                                   % mask unused outputs
cons = cons + (~ANYmask);
nuls = zeros(1,k*nouts);
sumDOF = sum([nuls;DOF1]);                              % sum of DOF's
NoRule = sumDOF == 0;                                   % no rule applicable
sumDOF = sumDOF + NoRule;                               % set zeros to one
aux = ones(1,k*nouts);
c = (mfs(:,2) + mfs(:,5))/2*aux;                        % center of support
s = (mfs(:,3) + mfs(:,4))/2*aux - c;                    % slope
y = zeros(k,nouts);                                     
def = aux(1:k)'*(def.*aux(1:nouts));                    % expand def
y(:) = sum([nuls;DOF1.*(c(cons)+ ...                    % calculate output
       DOF1.*s(cons))])./sumDOF + def(:)'.*NoRule;
DOF = DOF';

