function c=or_re(a,b,r)
% OR_RE(A,B,R) Restricted OR defined as:
%
% OR_RE(A,B,R) =    OR_PR(A,B) - R*(OR_ZA(A,B)-OR_PR(A,B)) for R >= 0
%
%                   OR_PR(A,B) - R*(OR_PR(A,B)-OR_LU(A,B)) for R <  0
%
%       R(A,B) = 1 when A and B are strongly positively associated
%       R(A,B) =-1 when A and B are strongly negatively associated
%       R(A,B) = 0 when A and B are independent of each other
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A * B, where *
%       is RE_OR(Ax,Bx).
%
%       C = OR_RE(A,r) calculates union of all rows in A.
%
%       See also OR, OR_ZA, OR_LU, OR_PR.

% (c) Robert Babuska, March 1993

[am,an] = size(a);
if nargin == 3,
  [bm,bn] = size(b);
  if ( am > 1 & an == 1 & bn > 1 )
    a = a * ones(1,bn);
    if ( bm == 1 )
        b = ones(am,1) * b;
    end;
  end;
  c = a + b - a.*b;
  if (r >= 0)
    c = c + r*(max(a,b) - c);
  else
    c = c + r*(c - min(a+b,1));
  end;
else
  c = a(1,:);
  for i = 2 : am,
    d = a(i,:) + c - a(i,:).*c;
    if (b >= 0)
      c = d + b*(max(a(i,:),c) - d);
    else
      c = d + b*(d - min(a(i,:)+c,1));
    end;
  end;
end;

