function c=snorm(a,b,p,ntype)
%       C=SNORM(A,B,P,NTYPE) The general s-norm (t-conorm) function,
%       where NTYPE can be
%                       'du' ... Dubois & Prade (default, see S_DU)
%                       'do' ... Dombi                   (see S_DO)
%                       'la' ... lambda                  (see S_LA)
%                       'ya' ... Yager                   (see S_YA)
%                       'fr' ... Frank                   (see S_FR)
%                       'ha' ... Hamacher                (see S_HA)
%                       'sk' ... Schweizer & Sklar       (see S_SK)
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A x B.
%
%       See also S_DO, S_DU, S_LA, S_YA, S_FR, S_HA, S_SK.

% (c) Robert Babuska, March 1993

if (nargin < 4), ntype = 'du'; end;

am = length(a(:,1)); bn = length(b(1,:));
if ( am > 1 & bn > 1 )
    a=a*ones(1,bn); b=ones(am,1)*b;
end;

if (ntype == 'du')
  c = (a + b - a.*b - min(min(a,b),1-p))./max(max(1-a,1-b),p);
  return;
end;
if (ntype == 'do')
  c = (1 + ((a.^(-1) - 1).^(-p) + (b.^(-1) - 1).^(-p)).^(-1/p)).^(-1);
  return;
end;
if (ntype == 'la')
  c = min(1, a + b + p*a.*b);
  return;
end;
if (ntype == 'ya')
  ab = a.^p + b.^p;
  if (ab < 1)
      c = ab.^(1/p);
  else
      c = min(1,ab.^(1/p));
  end;
  return;
end;

if (ntype == 'fr')
  c = 1 - log(1 + 1/(p-1) .* (p.^(1-a) - 1) .* (p.^(1-b) - 1))/log(p);
  return;
end;

if (ntype == 'ha')
  c = (a + b - (2-p)*a.*b)./(1 - (1-p)*a.*b);
  return;
end;

if (ntype == 'sk')
  c = (a.^p + b.^p - (a.^p).*(b.^p)).^(1/p);
  return;
end;


