function c=s_la(a,b,lambda)
%       C=S_LA(A,B,LAMBDA) The lambda t-conorm.
%       LAMBDA > -1
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A x B.
%
%       S_LA(A,LAMBDA) calculates the t-conorm between all rows in A.
%       In this case, LAMBDA can be a vector of parameters.
%
%       See also SNORM, S_DU, S_DO, S_YA, S_FR, S_HA, S_SK.

% (c) Robert Babuska, March 1993

am = size(a,1); bn = size(b,2);
if nargin == 3,
  if ( am > 1 & bn > 1 )
    a=a*ones(1,bn); b=ones(am,1)*b;
  end;
  c = min(1, a + b + lambda*a.*b);
else
    for j = length(b) : -1 : 1,
      c(j,:) = a(1,:);
      for i = 2 : am,
        c(j,:) = min(1, a(i,:) + c(j,:) + b(j)*a(i,:).*c(j,:));
      end;
    end;
end;
