function c=tnorm(a,b,p,ntype)
%       C=TNORM(A,B,P,NTYPE) The general t-norm function, where
%       NTYPE can be
%                       'du' ... Dubois & Prade (default, see T_DU)
%                       'do' ... Dombi                   (see T_DO)
%                       'la' ... lambda                  (see T_LA)
%                       'ya' ... Yager                   (see T_YA)
%                       'fr' ... Frank                   (see T_FR)
%                       'ha' ... Hamacher                (see T_HA)
%                       'sk' ... Schweizer & Sklar       (see T_SK)
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A x B.
%
%       See also T_DU, T_DO, T_LA, T_YA, T_FR, T_HA, T_SK.

% (c) Robert Babuska, March 1993

if (nargin < 4), ntype = 'du'; end;

am = length(a(:,1)); bn = length(b(1,:));
if ( am > 1 & bn > 1 )
    a=a*ones(1,bn); b=ones(am,1)*b;
end;

if (ntype == 'du'), c = (a.*b)./max(max(a,b),p); return; end;
if (ntype == 'do')
  c = (1 + ((a.^(-1) - 1).^p+ (b.^(-1) - 1).^p).^(1/p)).^(-1);
  return;
end;
if (ntype == 'la')
  c = max(0,(p + 1)*(a + b - 1) - p*a.*b);
  return;
end;
if (ntype == 'ya')
  ab = (1 - a).^p + (1 - b).^p;
  if (ab < 1)
      c = 1 - ab.^(1/p);
  else
      c = 1 - min(1,ab.^(1/p));
  end;
  return;
end;

if (ntype == 'fr')
  c = log(1 + 1/(p-1) .* (p.^a - 1) .* (p.^b - 1))/log(p);
  return;
end;

if (ntype == 'ha')
  c = (a.*b)./(p + (1-p)*(a + b - a.*b));
  return;
end;

if (ntype == 'sk')
  a1 = 1 - a; b1 = 1 - b;
  c = 1 - (a1.^p + b1.^p - (a1.^p).*(b1.^p)).^(1/p);
  return;
end;


