function c=t_ya(a,b,p)
%       C=T_YA(A,B,P) The t-norm proposed by Yager.
%       P > 0
%
%       If A and B are both row or column vectors, then C
%       is also a row or column vector. If A is a column vector
%       and B a row vector, then a matrix C is returned,
%       representing the Cartesian product A x B.
%
%       T_YA(A,P) calculates the t-norm between all rows in A.
%       In this case, P can be a vector of parameters.
%
%       See also TNORM, T_DU, T_LA, T_DO, T_FR, T_HA, T_SK.

% (c) Robert Babuska, March 1993


am = size(a,1); bn = size(b,2);
if nargin == 3,
  if ( am > 1 & bn > 1 )
    a=a*ones(1,bn); b=ones(am,1)*b;
  end;
  ab = (1 - a).^p + (1 - b).^p;
  if (ab < 1)
    c = 1 - ab.^(1/p);
  else
    c = 1 - min(1,ab.^(1/p));
  end;
else
    for j = length(b) : -1 : 1,
      c(j,:) = a(1,:);
      for i = 2 : am,
        ac = (1 - a(i,:)).^b(j) + (1 - c(j,:)).^b(j);
        if (ac < 1)
          c(j,:) = 1 - ac.^(1/b(j));
        else
          c(j,:) = 1 - min(1,ac.^(1/b(j)));
        end;
      end;
    end;
end;
